@@ -16,6 +16,16 @@ def whitespace_tokenize(text, sep=" "):
 	tokens = text.split(sep)
 	return tokens
 
+def split_string(text, sep=" ", keep_sep=False):
+	res_text_list = list()
+	for _word in text.split(sep):
+		if keep_sep is False:
+			if len(_word) != 0:
+				res_text_list.append(_word)
+		else:
+			res_text_list.append(_word)
+	return res_text_list
+
 def token_en_number_seq_words(text, save_position=False):
 	text = text.replace(" ", "")
 	remain_text = ""
